@@ -1,5 +1,6 @@
 import csv
 import inspect
+import json
 from collections.abc import Sequence
 from io import BytesIO, StringIO
 from typing import Any
@@ -14,6 +15,7 @@ from fastadmin.models.schemas import ModelFieldWidgetSchema, WidgetType
 class BaseModelAdmin:
     """Base class for model admin"""
 
+    # Use it only if you use several orms in your project.
     model_name_prefix: str | None = None
 
     # Widgets for fields. Overload widgets in your ModelAdmin class using this parameter.
@@ -434,17 +436,27 @@ class BaseModelAdmin:
         fields = self.get_model_fields_with_widget_types(with_m2m=False)
 
         export_fields = [f.name for f in fields]
+        output = StringIO()
         if not export_format or export_format == ExportFormat.CSV:
-            output = StringIO()
             writer = csv.DictWriter(output, fieldnames=export_fields)
             writer.writeheader()
             for obj in objs:
                 obj_dict = await self.serialize_obj(obj, list_view=True)
                 obj_dict = {k: v for k, v in obj_dict.items() if k in export_fields}
                 writer.writerow(obj_dict)
-            output.seek(0)
-            return output
-        return None
+        if not export_format or export_format == ExportFormat.JSON:
+
+            class JSONEncoder(json.JSONEncoder):
+                def default(self, obj):
+                    try:
+                        return super().default(obj)
+                    except TypeError:
+                        return str(obj)
+
+            json.dump([await self.serialize_obj(obj, list_view=True) for obj in objs], output, cls=JSONEncoder)
+
+        output.seek(0)
+        return output
 
     def has_add_permission(self, user_id: UUID | int | None = None) -> bool:
         """This method is used to check if user has permission to add new model instance.
@@ -557,5 +569,13 @@ class ModelAdmin(BaseModelAdmin):
         """
         raise NotImplementedError
 
+    async def change_password(self, id: UUID | int, password: str) -> None:
+        """This method is used to change user password.
+
+        :params id: An user id.
+        :params password: A new password.
+        """
+        raise NotImplementedError
+
 
 admin_models: dict[Any, ModelAdmin] = {}
