@@ -9,6 +9,7 @@ class WidgetType(str, Enum):
 
     Input = "Input"
     InputNumber = "InputNumber"
+    PasswordInput = "PasswordInput"
     TextArea = "TextArea"
     RichTextArea = "RichTextArea"
     Select = "Select"
@@ -104,7 +105,7 @@ class BaseModelSchema(BaseModel):
 class InlineModelSchema(BaseModelSchema):
     """Inline model schema"""
 
-    fk_name: str | None
+    fk_name: str
     max_num: int | None
     min_num: int | None
     verbose_name: str | None
